@@ -30,7 +30,6 @@ Copyright_License {
 
 namespace Environment {
 static Java::TrivialClass cls;
-static jmethodID getExternalStorageDirectory_method;
 static jmethodID getExternalStoragePublicDirectory_method;
 } // namespace Environment
 
@@ -39,16 +38,9 @@ Environment::Initialise(JNIEnv *env)
 {
   cls.Find(env, "android/os/Environment");
 
-  getExternalStorageDirectory_method =
-    env->GetStaticMethodID(cls, "getExternalStorageDirectory",
-                           "()Ljava/io/File;");
-
   getExternalStoragePublicDirectory_method =
     env->GetStaticMethodID(cls, "getExternalStoragePublicDirectory",
                            "(Ljava/lang/String;)Ljava/io/File;");
-  if (getExternalStoragePublicDirectory_method == nullptr)
-    /* needs API level 8 */
-    env->ExceptionClear();
 }
 
 void
@@ -57,32 +49,9 @@ Environment::Deinitialise(JNIEnv *env)
   cls.Clear(env);
 }
 
-static Java::String
-getExternalStorageDirectory(JNIEnv *env)
-{
-  Java::File file{
-    env,
-    env->CallStaticObjectMethod(Environment::cls,
-                                Environment::getExternalStorageDirectory_method),
-  };
-
-  return file.GetAbsolutePathChecked();
-}
-
-AllocatedPath
-Environment::getExternalStorageDirectory() noexcept
-{
-  JNIEnv *env = Java::GetEnv();
-  return Java::ToPathChecked(::getExternalStorageDirectory(env));
-}
-
 static Java::String
 getExternalStoragePublicDirectory(JNIEnv *env, const char *type)
 {
-  if (Environment::getExternalStoragePublicDirectory_method == nullptr)
-    /* needs API level 8 */
-    return nullptr;
-
   Java::String type2(env, type);
   Java::File file(env, env->CallStaticObjectMethod(Environment::cls,
                                                    Environment::getExternalStoragePublicDirectory_method,
