@@ -40,12 +40,12 @@ ConditionMonitorWind::CheckCondition(const NMEAInfo &basic,
   }
 
   auto mag_change = fabs(wind.norm - last_wind.norm);
-  auto dir_change = (wind.bearing - last_wind.bearing).AsDelta().AbsoluteDegrees();
+  auto dir_change = (wind.bearing - last_wind.bearing).AsDelta().Absolute();
 
   if (mag_change > 2.5)
     return true;
 
-  return wind.norm > 5 && dir_change > 45;
+  return wind.norm > 5 && dir_change > Angle::Degrees(45);
 }
 
 void
