@@ -24,62 +24,8 @@ Copyright_License {
 #include "MessageParser.hpp"
 #include "Checksum.hpp"
 
-#define IMICOMM_MAX_MSG_SIZE (sizeof(TMsg))
-
-namespace IMI {
-namespace MessageParser {
-  /** Parser state */
-  enum TState {
-    /** Synchronization bits not found */
-    STATE_NOT_SYNC,
-    /** Parsing message body */
-    STATE_COMM_MSG
-  } state;
-
-  static union {
-  /** Parsed message buffer */
-    IMIBYTE buffer[IMICOMM_MAX_MSG_SIZE];
-    TMsg tmsg;
-  };
-
-  /** Current position in a message buffer */
-  unsigned buffer_pos;
-  /** Remaining number of bytes of the message to parse */
-  unsigned bytes_left;
-
-  /**
-   * Cast the head of the buffer to a TMsg.
-   */
-  TMsg &GetMessage();
-
-  /**
-   * @brief Verifies received message
-   *
-   * @param msg Message to check
-   * @param size Size of received message
-   *
-   * @return Verification status
-   */
-  bool Check(const TMsg *msg, IMIDWORD size);
-}
-}
-
-IMI::TMsg &
-IMI::MessageParser::GetMessage()
-{
-  return tmsg;
-}
-
-void
-IMI::MessageParser::Reset()
-{
-  bytes_left = 0;
-  buffer_pos = 0;
-  state = STATE_NOT_SYNC;
-}
-
 bool
-IMI::MessageParser::Check(const TMsg *msg, IMIDWORD size)
+IMI::MessageParser::Check(const TMsg *msg, IMIDWORD size) noexcept
 {
   // minimal size of comm message
   if (size < IMICOMM_MSG_HEADER_SIZE + IMICOMM_CRC_LEN)
@@ -105,11 +51,11 @@ IMI::MessageParser::Check(const TMsg *msg, IMIDWORD size)
   return crc1 == crc2;
 }
 
-const IMI::TMsg *
-IMI::MessageParser::Parse(const IMIBYTE _buffer[], int size)
+std::optional<IMI::TMsg>
+IMI::MessageParser::Parse(const IMIBYTE _buffer[], int size) noexcept
 {
   const IMIBYTE *ptr = _buffer;
-  const TMsg *msg = 0;
+  std::optional<TMsg> msg;
 
   for (; size; size--) {
     IMIBYTE byte = *ptr++;
@@ -147,7 +93,7 @@ IMI::MessageParser::Parse(const IMIBYTE _buffer[], int size)
         if (bytes_left == 0) {
           // end of message
           if (Check(&GetMessage(), buffer_pos))
-            msg = &GetMessage();
+            msg = GetMessage();
 
           // prepare parser for the next message
           Reset();
