@@ -28,6 +28,7 @@ Copyright_License {
 #include "Device/Driver.hpp"
 #include "Device/SettingsMap.hpp"
 #include "thread/Mutex.hxx"
+#include "util/StaticString.hxx"
 
 #include <atomic>
 #include <cstdint>
@@ -50,17 +51,27 @@ class LXDevice: public AbstractDevice
   /**
    * Is this ia Colibri or LX20 or a similar "old" logger?  This is
    * initialised to true if the NMEA baud rate is configured to 4800,
-   * which disables the advanced V7/Nano protocol, to avoid confusing
+   * which disables the advanced LX Vario/Nano protocol, to avoid confusing
    * the Colibri.  It is cleared as soon as a "modern" LX product is
    * detected (passively).
    */
   bool is_colibri;
 
+  /*
+   * Indicates whether pass-through mode should be used
+   */
+  bool use_pass_through;
+
   /**
    * Was a LXNAV V7 detected?
    */
   bool is_v7;
 
+  /**
+   * Was a LXNAV S series vario detected?
+   */
+  bool is_sVario;
+
   /**
    * Was a LXNAV Nano detected?
    */
@@ -77,14 +88,14 @@ class LXDevice: public AbstractDevice
   bool is_lx16xx;
 
   /**
-   * Was a V7 with a Nano on the GPS port detected?
+   * Was a vario with a Nano on the GPS port detected?
    */
   bool is_forwarded_nano;
 
   /**
-   * Settings that were received in PLXV0 (LXNAV V7) sentences.
+   * Settings that were received in PLXV0 (LXNAV Vario) sentences.
    */
-  DeviceSettingsMap<std::string> v7_settings;
+  DeviceSettingsMap<std::string> lxnav_vario_settings;
 
   /**
    * Settings that were received in PLXVC (LXNAV Nano) sentences.
@@ -97,10 +108,10 @@ class LXDevice: public AbstractDevice
 
 public:
   LXDevice(Port &_port, unsigned baud_rate, unsigned _bulk_baud_rate,
-           bool _port_is_nano=false)
+           bool _use_pass_through, bool _port_is_nano=false)
     :port(_port), bulk_baud_rate(_bulk_baud_rate),
      busy(false),
-     is_colibri(baud_rate == 4800),
+     is_colibri(baud_rate == 4800), use_pass_through(_use_pass_through),
      is_v7(false), is_nano(_port_is_nano), port_is_nano(_port_is_nano),
      is_lx16xx(false), is_forwarded_nano(false),
      mode(Mode::UNKNOWN), old_baud_rate(0) {}
@@ -112,6 +123,20 @@ public:
     return is_v7;
   }
 
+  /**
+   * Was a LXNAV S series vario detected?
+   */
+  bool IsSVario() const {
+    return is_sVario;
+  }
+
+  /**
+   * Was a LXNAV vario device detected?
+   */
+  bool IsLXNAVVario() const {
+    return IsV7() || IsSVario();
+  }
+
   /**
    * Was a LXNAV Nano detected?
    */
@@ -119,6 +144,13 @@ public:
     return port_is_nano || is_nano || is_forwarded_nano;
   }
 
+  /**
+   * Was an LXNAV logger device detected?
+   */
+  bool IsLXNAVLogger() const {
+    return IsNano() || IsSVario();
+  }
+
   /**
    * Was a LXNavigation LX1600/1606 vario detected?
    */
@@ -126,42 +158,61 @@ public:
     return is_lx16xx;
   }
 
+  /**
+   * Can this device be managed by XCSoar?
+   */
+  bool IsManageable() const {
+    return IsV7() || IsSVario() || IsNano() || IsLX16xx();
+  }
+
+  bool UsePassThrough() {
+    return use_pass_through;
+  }
+
   void ResetDeviceDetection() {
-    is_v7 = is_nano = is_lx16xx = is_forwarded_nano = false;
+    is_v7 = is_sVario = is_nano = is_lx16xx = is_forwarded_nano = false;
+  }
+
+  void IdDeviceByName(NarrowString<16> productName)
+  {
+    is_v7 = productName.equals("V7");
+    is_sVario = productName.equals("NINC") || productName.equals("S8x");
+    is_nano = productName.equals("NANO") || productName.equals("NANO3") || productName.equals("NANO4");
+    is_lx16xx = productName.equals("1606") || productName.equals("1600");
   }
 
   /**
-   * Write a setting to a LXNAV V7.
+   * Write a setting to a LXNAV Vario.
    *
    * @return true if sending the command has succeeded (it does not
-   * indicate whether the V7 has understood and processed it)
+   * indicate whether the Vario has understood and processed it)
    */
-  bool SendV7Setting(const char *name, const char *value,
+  bool SendLXNAVVarioSetting(const char *name, const char *value,
                      OperationEnvironment &env);
 
   /**
-   * Request a setting from a LXNAV V7.  The V7 will send the value,
+   * Request a setting from a LXNAV Vario.  The Vario will send the value,
    * but this method will not wait for that.
    *
    * @return true if sending the command has succeeded (it does not
-   * indicate whether the V7 has understood and processed it)
+   * indicate whether the Vario has understood and processed it)
    */
-  bool RequestV7Setting(const char *name, OperationEnvironment &env);
+  bool RequestLXNAVVarioSetting(const char *name, OperationEnvironment &env);
 
   /**
    * Wait for the specified setting to be received.  Returns the value
    * on success, or an empty string on timeout.
    */
-  std::string WaitV7Setting(const char *name, OperationEnvironment &env,
+  std::string WaitLXNAVVarioSetting(const char *name, OperationEnvironment &env,
                             unsigned timeout_ms);
 
   /**
-   * Look up the given setting in the table of received LXNAV V7
+   * Look up the given setting in the table of received LXNAV Vario
    * values.  If the value does not exist, an empty string is
    * returned.
    */
   gcc_pure
-  std::string GetV7Setting(const char *name) const;
+  std::string GetLXNAVVarioSetting(const char *name) const;
 
   /**
    * Write a setting to a LXNAV Nano.
@@ -202,7 +253,7 @@ protected:
    * mode.  If the Nano is connected through a LXNAV V7, it will
    * enable pass-through mode on the V7.
    */
-  bool EnableNanoNMEA(OperationEnvironment &env);
+  bool EnableLoggerNMEA(OperationEnvironment &env);
 
   bool EnableCommandMode(OperationEnvironment &env);
 
