@@ -71,6 +71,8 @@ public:
 class TerrainDisplayConfigPanel final
   : public RowFormWidget, DataFieldListener {
 
+  bool have_terrain_preview;
+
 protected:
   TerrainRendererSettings terrain_settings;
 
@@ -105,7 +107,7 @@ TerrainDisplayConfigPanel::ShowTerrainControls()
   SetRowVisible(TerrainContrast, show);
   SetRowVisible(TerrainBrightness, show);
   SetRowVisible(TerrainContours, show);
-  if (terrain != nullptr)
+  if (have_terrain_preview)
     SetRowVisible(TerrainPreview, show);
 }
 
@@ -134,7 +136,7 @@ TerrainDisplayConfigPanel::UpdateTerrainPreview()
     GetValueInteger(TerrainContours);
 
   // Invalidate terrain preview
-  if (terrain != nullptr)
+  if (have_terrain_preview)
     ((TerrainPreviewWindow &)GetRow(TerrainPreview)).SetSettings(terrain_settings);
 }
 
@@ -270,7 +272,8 @@ TerrainDisplayConfigPanel::Prepare(ContainerWindow &parent,
   GetDataField(TerrainContours).SetListener(this);
   SetExpertRow(TerrainContours);
 
-  if (::terrain != nullptr) {
+  have_terrain_preview = ::terrain != nullptr;
+  if (have_terrain_preview) {
     WindowStyle style;
     style.Border();
 
