@@ -97,6 +97,9 @@ WaypointDisplayConfigPanel::Prepare(ContainerWindow &parent,
       N_("The first 5 letters of the waypoint name are displayed.") },
     { (unsigned)WaypointRendererSettings::DisplayTextType::NONE,
       N_("None"), N_("No waypoint name is displayed.") },
+    { (unsigned)WaypointRendererSettings::DisplayTextType::SHORT_NAME,
+      N_("Short Name"),
+      N_("The short name of each waypoint is displayed. If unavailable, the first five letters of the full name are displayed.") },
     { 0 }
   };
   AddEnum(_("Label format"), _("Determines how labels are displayed with each waypoint"),
