@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -27,22 +27,19 @@ Copyright_License {
 #include "../dlgTaskHelpers.hpp"
 #include "Dialogs/Message.hpp"
 #include "Dialogs/Waypoint/WaypointDialogs.hpp"
-#include "Screen/Canvas.hpp"
 #include "Screen/Layout.hpp"
-#include "Screen/Key.h"
+#include "ui/event/KeyCode.hpp"
 #include "Renderer/TwoTextRowsRenderer.hpp"
 #include "Interface.hpp"
-#include "Screen/SingleWindow.hpp"
-#include "Form/Button.hpp"
+#include "Form/ButtonPanel.hpp"
 #include "Form/List.hpp"
+#include "Widget/ButtonPanelWidget.hpp"
 #include "Widget/ListWidget.hpp"
 #include "Widget/TextWidget.hpp"
 #include "Widget/TwoWidgets.hpp"
 #include "Formatter/UserUnits.hpp"
 #include "Formatter/AngleFormatter.hpp"
 #include "Look/DialogLook.hpp"
-#include "Look/TaskLook.hpp"
-#include "Look/AirspaceLook.hpp"
 #include "Engine/Task/Ordered/OrderedTask.hpp"
 #include "Engine/Task/Ordered/Points/StartPoint.hpp"
 #include "Engine/Task/Ordered/Points/IntermediatePoint.hpp"
@@ -50,178 +47,29 @@ Copyright_License {
 #include "Language/Language.hpp"
 #include "Renderer/OZPreviewRenderer.hpp"
 #include "Renderer/SymbolButtonRenderer.hpp"
-#include "Util/Macros.hpp"
+#include "util/Macros.hpp"
+#include "util/StringCompare.hxx"
 #include "UIGlobals.hpp"
 
-#include <assert.h>
-#include <stdio.h>
-
-enum Buttons {
-  EDIT = 100,
-  MUTATE,
-  DOWN,
-  UP,
-  REVERSE,
-  CLEAR_ALL,
-};
-
-/**
- * The bottom panel showing four buttons.  Internally, there are five
- * button objects, because the "down" and the "mutate" buttons are
- * exclusive.
- */
-class TaskEditButtons final : public NullWidget {
-  ActionListener *listener;
-
-  Button edit_button, mutate_button;
-  Button down_button, up_button;
-  Button reverse_button, clear_all_button;
-  bool visible;
-
-  bool show_edit, show_mutate, show_down, show_up, show_reverse;
-
-  struct Layout {
-    PixelRect edit, down, up, reverse, clear_all;
-  };
-
-public:
-  TaskEditButtons()
-    :visible(false), show_edit(false), show_mutate(false),
-     show_down(false), show_up(false), show_reverse(false) {}
-
-  void SetListener(ActionListener &_listener) {
-    assert(!visible);
-
-    listener = &_listener;
-  }
-
-  void Update(bool _edit, bool _mutate, bool _down, bool _up, bool _reverse) {
-    show_edit = _edit;
-    show_mutate = _mutate;
-    show_down = _down;
-    show_up = _up;
-    show_reverse = _reverse;
-
-    if (visible)
-      UpdateVisibility();
-  }
-
-private:
-  void UpdateVisibility() {
-    assert(visible);
-
-    edit_button.SetVisible(show_edit);
-    mutate_button.SetVisible(show_mutate);
-    down_button.SetVisible(show_down);
-    up_button.SetVisible(show_up);
-    reverse_button.SetVisible(show_reverse);
-    clear_all_button.Show();
-  }
-
-  Layout CalculateLayout(const PixelRect &rc) const {
-    const PixelScalar dx = (rc.right - rc.left) / 5;
-
-    return {
-      { rc.left         , rc.top, rc.left +     dx, rc.bottom },
-      { rc.left +     dx, rc.top, rc.left + 2 * dx, rc.bottom },
-      { rc.left + 2 * dx, rc.top, rc.left + 3 * dx, rc.bottom },
-      { rc.left + 3 * dx, rc.top, rc.left + 4 * dx, rc.bottom },
-      { rc.left + 4 * dx, rc.top, rc.right        , rc.bottom },
-    };
-  }
-
-  void UpdatePositions(const PixelRect &rc) {
-    assert(visible);
-
-    const Layout layout = CalculateLayout(rc);
-
-    edit_button.Move(layout.edit);
-    mutate_button.Move(layout.down);
-    down_button.Move(layout.down);
-    up_button.Move(layout.up);
-    reverse_button.Move(layout.reverse);
-    clear_all_button.Move(layout.clear_all);
-  }
-
-public:
-  /* virtual methods from Widget */
-  PixelSize GetMinimumSize() const override {
-    return { ::Layout::Scale(180u),
-        ::Layout::GetMinimumControlHeight() };
-  }
-
-  PixelSize GetMaximumSize() const override {
-    return { ::Layout::Scale(400u),
-        ::Layout::GetMaximumControlHeight() };
-  }
-
-  void Prepare(ContainerWindow &parent, const PixelRect &rc) override {
-    assert(!visible);
-
-    WindowStyle style;
-    style.Hide();
-    style.TabStop();
-
-    const ButtonLook &look = UIGlobals::GetDialogLook().button;
-
-    const Layout layout = CalculateLayout(rc);
-    edit_button.Create(parent, look, _("Edit Point"),
-                       layout.edit, style,
-                       *listener, EDIT);
-    mutate_button.Create(parent, look, _("Make Finish"),
-                         layout.down, style,
-                         *listener, MUTATE);
-    down_button.Create(parent, layout.down, style,
-                       new SymbolButtonRenderer(look, _T("v")),
-                       *listener, DOWN);
-    up_button.Create(parent, layout.down, style,
-                     new SymbolButtonRenderer(look, _T("^")),
-                     *listener, UP);
-    reverse_button.Create(parent, look, _("Reverse"),
-                          layout.reverse, style,
-                          *listener, REVERSE);
-    clear_all_button.Create(parent, look, _("Clear All"),
-                            layout.clear_all, style,
-                            *listener, CLEAR_ALL);
-  }
-
-  void Show(const PixelRect &rc) override {
-    assert(!visible);
-    visible = true;
-
-    UpdatePositions(rc);
-    UpdateVisibility();
-  }
-
-  void Hide() override {
-    assert(visible);
-    visible = false;
-
-    edit_button.Hide();
-    mutate_button.Hide();
-    down_button.Hide();
-    up_button.Hide();
-    reverse_button.Hide();
-    clear_all_button.Hide();
-  }
-
-  void Move(const PixelRect &rc) override {
-    UpdatePositions(rc);
-  }
-};
+#include <cassert>
 
 class TaskEditPanel
-  : public ListWidget, public ActionListener {
+  : public ListWidget {
   TaskManagerDialog &dialog;
 
   const TaskLook &task_look;
   const AirspaceLook &airspace_look;
 
-  OrderedTask **ordered_task_pointer, *ordered_task;
+  std::unique_ptr<OrderedTask> &ordered_task_pointer;
+  OrderedTask *ordered_task;
   bool *task_modified;
 
   TextWidget &summary;
-  TaskEditButtons &buttons;
+
+  ButtonPanelWidget *buttons_widget;
+  Button *edit_button, *mutate_button;
+  Button *down_button, *up_button;
+  Button *reverse_button, *clear_all_button;
 
   TwoWidgets *two_widgets;
 
@@ -230,17 +78,23 @@ class TaskEditPanel
 public:
   TaskEditPanel(TaskManagerDialog &_dialog,
                 const TaskLook &_task_look, const AirspaceLook &_airspace_look,
-                OrderedTask **_active_task, bool *_task_modified,
-                TextWidget &_summary, TaskEditButtons &_buttons)
+                std::unique_ptr<OrderedTask> &_active_task, bool *_task_modified,
+                TextWidget &_summary) noexcept
     :dialog(_dialog),
      task_look(_task_look), airspace_look(_airspace_look),
      ordered_task_pointer(_active_task), task_modified(_task_modified),
-     summary(_summary), buttons(_buttons), two_widgets(nullptr) {}
+     summary(_summary), two_widgets(nullptr) {}
 
   void SetTwoWidgets(TwoWidgets &_two_widgets) {
     two_widgets = &_two_widgets;
   }
 
+  void SetButtons(ButtonPanelWidget &_buttons) noexcept {
+    buttons_widget = &_buttons;
+  }
+
+  void CreateButtons(ButtonPanel &buttons) noexcept;
+
   void UpdateButtons();
 
   void MoveUp();
@@ -253,49 +107,59 @@ public:
   void OnMakeFinish();
 
   /* virtual methods from Widget */
-  void Prepare(ContainerWindow &parent, const PixelRect &rc) override;
+  void Prepare(ContainerWindow &parent, const PixelRect &rc) noexcept override;
 
-  void Unprepare() override {
-    DeleteWindow();
-  }
-
-  void ReClick() override;
-  void Show(const PixelRect &rc) override;
-  bool KeyPress(unsigned key_code) override;
+  void ReClick() noexcept override;
+  void Show(const PixelRect &rc) noexcept override;
 
 protected:
   void RefreshView();
 
 private:
-  /* virtual methods from ActionListener */
-  void OnAction(int id) override;
-
   /* virtual methods from List::Handler */
-  void OnPaintItem(Canvas &canvas, const PixelRect rc, unsigned idx) override;
-  void OnCursorMoved(unsigned index) override;
-  bool CanActivateItem(unsigned index) const override;
-  void OnActivateItem(unsigned index) override;
+  void OnPaintItem(Canvas &canvas, const PixelRect rc,
+                   unsigned idx) noexcept override;
+  void OnCursorMoved(unsigned index) noexcept override;
+  bool CanActivateItem(unsigned index) const noexcept override;
+  void OnActivateItem(unsigned index) noexcept override;
 };
 
+void
+TaskEditPanel::CreateButtons(ButtonPanel &buttons) noexcept
+{
+  edit_button = buttons.Add(_("Edit Point"),
+                            [this](){ OnEditTurnpointClicked(); });
+  mutate_button = buttons.Add(_("Make Finish"),
+                              [this](){ OnMakeFinish(); });
+  down_button = buttons.Add(std::make_unique<SymbolButtonRenderer>(buttons.GetLook(), _T("v")),
+                            [this](){ MoveDown(); });
+  up_button = buttons.Add(std::make_unique<SymbolButtonRenderer>(buttons.GetLook(), _T("^")),
+                          [this](){ MoveUp(); });
+  reverse_button = buttons.Add(_("Reverse"),
+                               [this](){ ReverseTask(); });
+  clear_all_button = buttons.Add(_("Clear All"),
+                                 [this](){ OnClearAllClicked(); });
+
+  buttons.EnableCursorSelection();
+}
+
 void
 TaskEditPanel::UpdateButtons()
 {
   const unsigned index = GetList().GetCursorIndex();
 
-  buttons.Update(index < ordered_task->TaskSize(),
-                 index > 0 &&
-                 (index == ordered_task->TaskSize() - 1) &&
-                 !ordered_task->HasFinish(),
-                 (int)index < ((int)(ordered_task->TaskSize()) - 1),
-                 index > 0 && index < ordered_task->TaskSize(),
-                 ordered_task->TaskSize() >= 2);
+  edit_button->SetVisible(index < ordered_task->TaskSize());
+  mutate_button->SetVisible(index > 0 &&
+                            (index == ordered_task->TaskSize() - 1) &&
+                            !ordered_task->HasFinish());
+  down_button->SetVisible((int)index < ((int)(ordered_task->TaskSize()) - 1));
+  up_button->SetVisible(index > 0 && index < ordered_task->TaskSize());
+  reverse_button->SetVisible(ordered_task->TaskSize() >= 2);
 }
 
 void
 TaskEditPanel::RefreshView()
 {
-  UpdateButtons();
-
   dialog.InvalidateTaskView();
 
   unsigned length = ordered_task->TaskSize();
@@ -304,6 +168,8 @@ TaskEditPanel::RefreshView()
   GetList().SetLength(length);
   GetList().Invalidate();
 
+  UpdateButtons();
+
   {
     TCHAR text[300];
     OrderedTaskSummary(ordered_task, text, false);
@@ -321,13 +187,13 @@ void TaskEditPanel::ReverseTask()
 
   const unsigned start_index = 0;
   const unsigned finish_index = ordered_task->TaskSize() - 1;
-  const Waypoint start_wp = ordered_task->GetTaskPoint(start_index).GetWaypoint();
-  const Waypoint finish_wp = ordered_task->GetTaskPoint(finish_index).GetWaypoint();
+  auto start_wp = ordered_task->GetTaskPoint(start_index).GetWaypointPtr();
+  auto finish_wp = ordered_task->GetTaskPoint(finish_index).GetWaypointPtr();
 
-  if (start_wp.location != finish_wp.location) {
+  if (start_wp->location != finish_wp->location) {
     // swap start/finish TP if at different location but leave OZ type intact
-    ordered_task->Relocate(start_index, finish_wp);
-    ordered_task->Relocate(finish_index, start_wp);
+    ordered_task->Relocate(start_index, std::move(finish_wp));
+    ordered_task->Relocate(finish_index, std::move(start_wp));
 
     // remove optional start points
     while (ordered_task->HasOptionalStarts())
@@ -366,44 +232,14 @@ TaskEditPanel::OnClearAllClicked()
   }
 }
 
-void
-TaskEditPanel::OnAction(int id)
-{
-  switch (id) {
-  case EDIT:
-    OnEditTurnpointClicked();
-    break;
-
-  case MUTATE:
-    OnMakeFinish();
-    break;
-
-  case UP:
-    MoveUp();
-    break;
-
-  case DOWN:
-    MoveDown();
-    break;
-
-  case REVERSE:
-    ReverseTask();
-    break;
-
-  case CLEAR_ALL:
-    OnClearAllClicked();
-    break;
-  }
-}
-
 void
 TaskEditPanel::OnPaintItem(Canvas &canvas, const PixelRect rc,
-                           unsigned DrawListIndex)
+                           unsigned DrawListIndex) noexcept
 {
   assert(DrawListIndex <= ordered_task->TaskSize());
 
   const unsigned padding = Layout::GetTextPadding();
-  const unsigned line_height = rc.bottom - rc.top;
+  const unsigned line_height = rc.GetHeight();
 
   TCHAR buffer[120];
 
@@ -415,28 +251,21 @@ TaskEditPanel::OnPaintItem(Canvas &canvas, const PixelRect rc,
 
   const OrderedTaskPoint &tp = ordered_task->GetTaskPoint(DrawListIndex);
   GeoVector leg = tp.GetNominalLegVector();
-  bool show_leg_info = leg.distance > fixed(0.01);
+  bool show_leg_info = leg.distance > 0.01;
 
   PixelRect text_rc = rc;
   text_rc.left += line_height + padding;
 
   if (show_leg_info) {
-    // Use small font for details
-    canvas.Select(row_renderer.GetSecondFont());
-
     // Draw leg distance
     FormatUserDistanceSmart(leg.distance, buffer, true);
-    unsigned width = canvas.CalcTextWidth(buffer);
-    const int x1 = rc.right - padding - width;
-    canvas.DrawText(x1, rc.top + row_renderer.GetFirstY(), buffer);
+    const int x1 = row_renderer.DrawRightFirstRow(canvas, rc, buffer);
 
     // Draw leg bearing
     FormatBearing(buffer, ARRAY_SIZE(buffer), leg.bearing);
-    width = canvas.CalcTextWidth(buffer);
-    const int x2 = rc.right - padding - width;
-    canvas.DrawText(x2, rc.top + row_renderer.GetSecondY(), buffer);
+    const int x2 = row_renderer.DrawRightSecondRow(canvas, rc, buffer);
 
-    text_rc.right = std::min(x1, x2) - padding;
+    text_rc.right = std::min(x1, x2);
   }
 
   // Draw details line
@@ -445,13 +274,13 @@ TaskEditPanel::OnPaintItem(Canvas &canvas, const PixelRect rc,
     row_renderer.DrawSecondRow(canvas, text_rc, buffer);
 
   // Draw turnpoint name
-  OrderedTaskPointLabel(tp.GetType(), tp.GetWaypoint().name.c_str(),
+  OrderedTaskPointLabel(tp.GetType(), tp.GetWaypointPtr()->name.c_str(),
                         DrawListIndex, buffer);
   row_renderer.DrawFirstRow(canvas, text_rc, buffer);
 
   // Draw icon
-  const RasterPoint pt(rc.left + line_height / 2,
-                       rc.top + line_height / 2);
+  const PixelPoint pt(rc.left + line_height / 2,
+                      rc.top + line_height / 2);
 
   const unsigned radius = line_height / 2 - padding;
   OZPreviewRenderer::Draw(canvas, tp.GetObservationZone(),
@@ -467,7 +296,7 @@ TaskEditPanel::OnEditTurnpointClicked()
 }
 
 bool
-TaskEditPanel::CanActivateItem(gcc_unused unsigned index) const
+TaskEditPanel::CanActivateItem(gcc_unused unsigned index) const noexcept
 {
   return true;
 }
@@ -484,9 +313,8 @@ TaskEditPanel::EditTaskPoint(unsigned ItemIndex)
     }
   } else if (!ordered_task->IsFull()) {
 
-    OrderedTaskPoint* point = nullptr;
     AbstractTaskFactory &factory = ordered_task->GetFactory();
-    const Waypoint* way_point =
+    auto way_point =
       ShowWaypointListDialog(ordered_task->TaskSize() > 0
                              ? ordered_task->GetPoint(ordered_task->TaskSize() - 1).GetLocation()
                              : CommonInterface::Basic().location,
@@ -494,11 +322,9 @@ TaskEditPanel::EditTaskPoint(unsigned ItemIndex)
     if (!way_point)
       return;
 
-    if (ItemIndex == 0) {
-      point = factory.CreateStart(*way_point);
-    } else {
-      point = factory.CreateIntermediate(*way_point);
-     }
+    auto point = ItemIndex == 0
+      ? (std::unique_ptr<OrderedTaskPoint>)factory.CreateStart(std::move(way_point))
+      : (std::unique_ptr<OrderedTaskPoint>)factory.CreateIntermediate(std::move(way_point));
     if (point == nullptr)
       return;
 
@@ -508,19 +334,17 @@ TaskEditPanel::EditTaskPoint(unsigned ItemIndex)
       ordered_task->UpdateGeometry();
       RefreshView();
     }
-
-    delete point;
   }
 }
 
 void
-TaskEditPanel::OnActivateItem(unsigned index)
+TaskEditPanel::OnActivateItem(unsigned index) noexcept
 {
   EditTaskPoint(index);
 }
 
 void
-TaskEditPanel::OnCursorMoved(gcc_unused unsigned index)
+TaskEditPanel::OnCursorMoved(gcc_unused unsigned index) noexcept
 {
   UpdateButtons();
 }
@@ -571,38 +395,8 @@ TaskEditPanel::MoveDown()
   RefreshView();
 }
 
-bool
-TaskEditPanel::KeyPress(unsigned key_code)
-{
-  switch (key_code){
-  case KEY_ESCAPE:
-    if (IsAltair() && GetList().HasFocus()){
-       dialog.FocusFirstControl();
-      return true;
-    }
-    return false;
-
-  case '6': /* F5 */
-    if (IsAltair()) {
-      MoveUp();
-      return true;
-    } else
-      return false;
-
-  case '7': /* F6 */
-    if (IsAltair()) {
-      MoveDown();
-      return true;
-    } else
-      return false;
-
-  default:
-    return false;
-  }
-}
-
 void
-TaskEditPanel::Prepare(ContainerWindow &parent, const PixelRect &rc)
+TaskEditPanel::Prepare(ContainerWindow &parent, const PixelRect &rc) noexcept
 {
   const DialogLook &look = UIGlobals::GetDialogLook();
 
@@ -610,20 +404,22 @@ TaskEditPanel::Prepare(ContainerWindow &parent, const PixelRect &rc)
              row_renderer.CalculateLayout(*look.list.font_bold,
                                           look.small_font));
 
-  ordered_task = *ordered_task_pointer;
+  CreateButtons(buttons_widget->GetButtonPanel());
+
+  ordered_task = ordered_task_pointer.get();
 }
 
 void
-TaskEditPanel::ReClick()
+TaskEditPanel::ReClick() noexcept
 {
   dialog.TaskViewClicked();
 }
 
 void
-TaskEditPanel::Show(const PixelRect &rc)
+TaskEditPanel::Show(const PixelRect &rc) noexcept
 {
-  if (ordered_task != *ordered_task_pointer) {
-    ordered_task = *ordered_task_pointer;
+  if (ordered_task != ordered_task_pointer.get()) {
+    ordered_task = ordered_task_pointer.get();
     GetList().SetCursorIndex(0);
   }
 
@@ -632,20 +428,27 @@ TaskEditPanel::Show(const PixelRect &rc)
   ListWidget::Show(rc);
 }
 
-Widget *
+std::unique_ptr<Widget>
 CreateTaskEditPanel(TaskManagerDialog &dialog,
                     const TaskLook &task_look,
                     const AirspaceLook &airspace_look,
-                    OrderedTask **active_task, bool *task_modified)
+                    std::unique_ptr<OrderedTask> &active_task,
+                    bool *task_modified) noexcept
 {
-  TaskEditButtons *buttons = new TaskEditButtons();
-  TextWidget *summary = new TextWidget();
-  TaskEditPanel *widget = new TaskEditPanel(dialog, task_look, airspace_look,
-                                            active_task, task_modified,
-                                            *summary, *buttons);
-  buttons->SetListener(*widget);
-  TwoWidgets *tw1 = new TwoWidgets(widget, summary);
-  widget->SetTwoWidgets(*tw1);
-  TwoWidgets *tw2 = new TwoWidgets(tw1, buttons);
-  return tw2;
+  auto summary = std::make_unique<TextWidget>();
+  auto widget = std::make_unique<TaskEditPanel>(dialog, task_look, airspace_look,
+                                                active_task, task_modified,
+                                                *summary);
+  auto tw1 = std::make_unique<TwoWidgets>(std::move(widget),
+                                          std::move(summary));
+
+  auto &w = (TaskEditPanel &)tw1->GetFirst();
+  w.SetTwoWidgets(*tw1);
+
+  auto buttons = std::make_unique<ButtonPanelWidget>(std::move(tw1),
+                                                     ButtonPanelWidget::Alignment::BOTTOM);
+
+  w.SetButtons(*buttons);
+
+  return buttons;
 }
