@@ -2,7 +2,7 @@
   Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -39,18 +39,14 @@
 #include "Blackboard/BlackboardListener.hpp"
 #include "Language/Language.hpp"
 #include "TeamActions.hpp"
-#include "Util/TruncateString.hpp"
-#include "Util/Macros.hpp"
+#include "util/StringCompare.hxx"
+#include "util/StringStrip.hxx"
+#include "util/TruncateString.hpp"
+#include "util/Macros.hpp"
 
 class TeamCodeWidget final
-  : public RowFormWidget, NullBlackboardListener, ActionListener {
+  : public RowFormWidget, NullBlackboardListener {
   enum Controls {
-    SET_CODE,
-    SET_WAYPOINT,
-    SET_FLARM_LOCK,
-  };
-
-  enum Buttons {
     OWN_CODE,
     MATE_CODE,
     RANGE,
@@ -72,13 +68,10 @@ private:
   void OnFlarmLockClicked();
 
   /* virtual methods from class Widget */
-  virtual void Prepare(ContainerWindow &parent,
-                       const PixelRect &rc) override;
-  virtual void Show(const PixelRect &rc) override;
-  virtual void Hide() override;
-
-  /* virtual methods from class ActionListener */
-  virtual void OnAction(int id) override;
+  void Prepare(ContainerWindow &parent,
+               const PixelRect &rc) noexcept override;
+  void Show(const PixelRect &rc) noexcept override;
+  void Hide() noexcept override;
 
   /* virtual methods from class BlackboardListener */
   virtual void OnCalculatedUpdate(const MoreData &basic,
@@ -88,14 +81,14 @@ private:
 inline void
 TeamCodeWidget::CreateButtons(WidgetDialog &buttons)
 {
-  buttons.AddButton(_("Set code"), *this, SET_CODE);
-  buttons.AddButton(_("Set WP"), *this, SET_WAYPOINT);
-  buttons.AddButton(_("Flarm Lock"), *this, SET_FLARM_LOCK);
+  buttons.AddButton(_("Set code"), [this](){ OnCodeClicked(); });
+  buttons.AddButton(_("Set WP"), [this](){ OnSetWaypointClicked(); });
+  buttons.AddButton(_("Flarm Lock"), [this](){ OnFlarmLockClicked(); });
 }
 
 void
 TeamCodeWidget::Prepare(ContainerWindow &parent,
-                        const PixelRect &rc)
+                        const PixelRect &rc) noexcept
 {
   AddReadOnly(_("Own code"));
   AddReadOnly(_("Mate code"));
@@ -106,7 +99,7 @@ TeamCodeWidget::Prepare(ContainerWindow &parent,
 }
 
 void
-TeamCodeWidget::Show(const PixelRect &rc)
+TeamCodeWidget::Show(const PixelRect &rc) noexcept
 {
   Update(CommonInterface::Basic(), CommonInterface::Calculated());
   CommonInterface::GetLiveBlackboard().AddListener(*this);
@@ -114,7 +107,7 @@ TeamCodeWidget::Show(const PixelRect &rc)
 }
 
 void
-TeamCodeWidget::Hide()
+TeamCodeWidget::Hide() noexcept
 {
   RowFormWidget::Hide();
   CommonInterface::GetLiveBlackboard().RemoveListener(*this);
@@ -158,7 +151,7 @@ TeamCodeWidget::OnCalculatedUpdate(const MoreData &basic,
 inline void
 TeamCodeWidget::OnSetWaypointClicked()
 {
-  const Waypoint* wp =
+  const auto wp =
     ShowWaypointListDialog(CommonInterface::Basic().location);
   if (wp != nullptr) {
     CommonInterface::SetComputerSettings().team_code.team_code_reference_waypoint = wp->id;
@@ -191,7 +184,7 @@ TeamCodeWidget::OnFlarmLockClicked()
 {
   TeamCodeSettings &settings =
     CommonInterface::SetComputerSettings().team_code;
-  TCHAR newTeamFlarmCNTarget[settings.team_flarm_callsign.capacity()];
+  TCHAR newTeamFlarmCNTarget[decltype(settings.team_flarm_callsign)::capacity()];
   _tcscpy(newTeamFlarmCNTarget, settings.team_flarm_callsign.c_str());
 
   if (!TextEntryDialog(newTeamFlarmCNTarget, 4))
@@ -222,33 +215,15 @@ TeamCodeWidget::OnFlarmLockClicked()
   TeamActions::TrackFlarm(id, newTeamFlarmCNTarget);
 }
 
-void
-TeamCodeWidget::OnAction(int id)
-{
-  switch (id) {
-  case SET_CODE:
-    OnCodeClicked();
-    break;
-
-  case SET_WAYPOINT:
-    OnSetWaypointClicked();
-    break;
-
-  case SET_FLARM_LOCK:
-    OnFlarmLockClicked();
-    break;
-  }
-}
-
 void
 dlgTeamCodeShowModal()
 {
   const DialogLook &look = UIGlobals::GetDialogLook();
-  WidgetDialog dialog(look);
-  TeamCodeWidget widget(look);
-  dialog.CreateAuto(UIGlobals::GetMainWindow(), _("Team Code"), &widget);
-  widget.CreateButtons(dialog);
+  TWidgetDialog<TeamCodeWidget>
+    dialog(WidgetDialog::Auto{}, UIGlobals::GetMainWindow(),
+           look, _("Team Code"));
   dialog.AddButton(_("Close"), mrOK);
+  dialog.SetWidget(look);
+  dialog.GetWidget().CreateButtons(dialog);
   dialog.ShowModal();
-  dialog.StealWidget();
 }
