@@ -22,6 +22,7 @@
 #ifndef AIRSPACE_HPP
 #define AIRSPACE_HPP
 
+#include "Ptr.hpp"
 #include "Geo/Flat/FlatBoundingBox.hpp"
 
 #ifdef DO_PRINT
@@ -47,7 +48,7 @@ class FlatProjection;
  */
 class Airspace final : public FlatBoundingBox
 {
-  AbstractAirspace *airspace;
+  AirspacePtr airspace;
 
 public:
 
@@ -59,8 +60,8 @@ public:
    *
    * @return airspace letter inside envelope suitable for insertion in a search structure
    */
-  Airspace(AbstractAirspace &airspace,
-           const FlatProjection &projection);
+  Airspace(AirspacePtr _airspace,
+           const FlatProjection &projection) noexcept;
 
   /**
    * Checks whether an aircraft is inside the airspace.
@@ -70,7 +71,7 @@ public:
    * @return true if aircraft is inside airspace
    */
   [[gnu::pure]]
-  bool IsInside(const AircraftState &loc) const;
+  bool IsInside(const AircraftState &loc) const noexcept;
 
   /**
    * Checks whether a point is inside the airspace lateral boundary.
@@ -80,7 +81,7 @@ public:
    * @return true if location is inside airspace
    */
   [[gnu::pure]]
-  bool IsInside(const GeoPoint &loc) const;
+  bool IsInside(const GeoPoint &loc) const noexcept;
 
   /**
    * Checks whether a line intersects with the airspace, by directing
@@ -94,62 +95,58 @@ public:
   [[gnu::pure]]
   AirspaceIntersectionVector Intersects(const GeoPoint &g1,
                                         const GeoPoint &end,
-                                        const FlatProjection &projection) const;
-
-  /**
-   * Destroys concrete airspace enclosed by this instance if present.
-   * Note that this should not be called by clients but only by the
-   * master store.  Many copies of this airspace may point to the same
-   * concrete airspace so have to be careful here.
-   *
-   */
-  void Destroy();
+                                        const FlatProjection &projection) const noexcept;
 
   /**
    * Accessor for contained AbstractAirspace
    *
    * @return Airspace letter
    */
-  AbstractAirspace &GetAirspace() const {
+  AbstractAirspace &GetAirspace() const noexcept {
     return *airspace;
   };
 
+  // TODO change to ConstAirspacePtr
+  AirspacePtr GetAirspacePtr() const noexcept {
+    return airspace;
+  };
+
   /**
    * Set terrain altitude for AGL-referenced airspace altitudes
    *
    * @param alt Height above MSL of terrain (m) at center
    */
-  void SetGroundLevel(double alt) const;
+  void SetGroundLevel(double alt) const noexcept;
 
   /**
    * Is it necessary to call SetGroundLevel() for this AbstractAirspace?
    */
   [[gnu::pure]]
-  bool NeedGroundLevel() const;
+  bool NeedGroundLevel() const noexcept;
 
   /**
    * Set QNH pressure for FL-referenced airspace altitudes
    *
    * @param press Atmospheric pressure model and QNH
    */
-  void SetFlightLevel(const AtmosphericPressure &press) const;
+  void SetFlightLevel(const AtmosphericPressure &press) const noexcept;
 
   /**
    * Set activity based on day mask
    *
    * @param days Mask of activity
    */
-  void SetActivity(const AirspaceActivity mask) const;
+  void SetActivity(const AirspaceActivity mask) const noexcept;
 
   /**
    * Clear the convex clearance polygon
    */
-  void ClearClearance() const;
+  void ClearClearance() const noexcept;
 
   /**
    * Equality operator, matches if contained airspace is the same
    */
-  bool operator==(Airspace const &a) const {
+  bool operator==(Airspace const &a) const noexcept {
     return &GetAirspace() == &a.GetAirspace();
   }
 
