@@ -31,7 +31,7 @@
 inline FlatGeoPoint
 RoutePolars::MSLIntercept(const int index, const FlatGeoPoint &fp,
                           double altitude,
-                          const FlatProjection &proj) const
+                          const FlatProjection &proj) const noexcept
 {
   const unsigned safe_index = ((unsigned)index) % ROUTEPOLAR_POINTS;
   const auto d = altitude * polar_glide.GetPoint(safe_index).inv_gradient;
@@ -46,7 +46,7 @@ RoutePolars::MSLIntercept(const int index, const FlatGeoPoint &fp,
 void
 RoutePolars::Initialise(const GlideSettings &settings, const GlidePolar &polar,
                         const SpeedVector &wind,
-                        const int _height_min_working)
+                        const int _height_min_working) noexcept
 {
   polar_glide.Initialise(settings, polar, wind, true);
   polar_cruise.Initialise(settings, polar, wind, false);
@@ -55,13 +55,13 @@ RoutePolars::Initialise(const GlideSettings &settings, const GlidePolar &polar,
 }
 
 unsigned
-RoutePolars::RoundTime(const unsigned val)
+RoutePolars::RoundTime(const unsigned val) noexcept
 {
   return val | 0x07;
 }
 
 unsigned
-RoutePolars::CalcTime(const RouteLink& link) const
+RoutePolars::CalcTime(const RouteLink &link) const noexcept
 {
   const int dh = link.second.altitude - link.first.altitude;
   if (dh < 0 && inv_mc <= 0)
@@ -100,14 +100,15 @@ RoutePolars::CalcTime(const RouteLink& link) const
 }
 
 double
-RoutePolars::CalcVHeight(const RouteLink &link) const
+RoutePolars::CalcVHeight(const RouteLink &link) const noexcept
 {
   return polar_glide.GetPoint(link.polar_index).gradient * link.d;
 }
 
 bool
 RoutePolars::CheckClearance(const RouteLink &e, const RasterMap* map,
-                            const FlatProjection &proj, RoutePoint& inp) const
+                            const FlatProjection &proj,
+                            RoutePoint &inp) const noexcept
 {
   if (!config.IsTerrainEnabled())
     return true;
@@ -130,9 +131,9 @@ RoutePolars::CheckClearance(const RouteLink &e, const RasterMap* map,
 }
 
 RouteLink
-RoutePolars::GenerateIntermediate(const RoutePoint& _dest,
-                                   const RoutePoint& _origin,
-                                   const FlatProjection &proj) const
+RoutePolars::GenerateIntermediate(const RoutePoint &_dest,
+                                  const RoutePoint &_origin,
+                                  const FlatProjection &proj) const noexcept
 {
   RouteLink link(_dest, _origin, proj);
   const int vh = CalcVHeight(link) + _dest.altitude;
@@ -145,7 +146,8 @@ RoutePolars::GenerateIntermediate(const RoutePoint& _dest,
 
 RouteLink
 RoutePolars::NeighbourLink(const RoutePoint &start, const RoutePoint &end,
-                           const FlatProjection &proj, const int sign) const
+                           const FlatProjection &proj,
+                           const int sign) const noexcept
 {
   const FlatGeoPoint d = FlatGeoPoint(end) - FlatGeoPoint(start);
 
@@ -177,7 +179,8 @@ RoutePolars::NeighbourLink(const RoutePoint &start, const RoutePoint &end,
 }
 
 bool
-RoutePolars::IsAchievable(const RouteLink& link, const bool check_ceiling) const
+RoutePolars::IsAchievable(const RouteLink &link,
+                          const bool check_ceiling) const noexcept
 {
   if (CanClimb())
     return true;
@@ -194,7 +197,7 @@ RoutePolars::IsAchievable(const RouteLink& link, const bool check_ceiling) const
 void
 RoutePolars::SetConfig(const RoutePlannerConfig& _config,
                        const int _cruise_alt,
-                       const int _ceiling_alt)
+                       const int _ceiling_alt) noexcept
 {
   config = _config;
 
@@ -206,7 +209,7 @@ RoutePolars::SetConfig(const RoutePlannerConfig& _config,
 }
 
 bool
-RoutePolars::CanClimb() const
+RoutePolars::CanClimb() const noexcept
 {
   return config.allow_climb && inv_mc > 0;
 }
@@ -214,7 +217,8 @@ RoutePolars::CanClimb() const
 GeoPoint
 RoutePolars::Intersection(const AGeoPoint &origin,
                           const AGeoPoint &destination,
-                          const RasterMap *map, const FlatProjection &proj) const
+                          const RasterMap *map,
+                          const FlatProjection &proj) const noexcept
 {
   if (map == nullptr || !map->IsDefined())
     return GeoPoint::Invalid();
@@ -232,9 +236,9 @@ RoutePolars::Intersection(const AGeoPoint &origin,
 }
 
 int
-RoutePolars::CalcGlideArrival(const AFlatGeoPoint& origin,
-                                const FlatGeoPoint& dest,
-                              const FlatProjection &proj) const
+RoutePolars::CalcGlideArrival(const AFlatGeoPoint &origin,
+                              const FlatGeoPoint &dest,
+                              const FlatProjection &proj) const noexcept
 {
   const RouteLink e(RoutePoint(dest, 0), origin, proj);
   return origin.altitude - CalcVHeight(e);
@@ -243,8 +247,8 @@ RoutePolars::CalcGlideArrival(const AFlatGeoPoint& origin,
 FlatGeoPoint
 RoutePolars::ReachIntercept(const int index, const AFlatGeoPoint &flat_origin,
                             const GeoPoint &origin,
-                            const RasterMap* map,
-                            const FlatProjection &proj) const
+                            const RasterMap *map,
+                            const FlatProjection &proj) const noexcept
 {
   const bool valid = map && map->IsDefined();
   const int altitude = flat_origin.altitude - GetSafetyHeight();
