@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -22,50 +22,49 @@ Copyright_License {
 */
 
 #include "Form/Frame.hpp"
-#include "Screen/AnyCanvas.hpp"
+#include "ui/canvas/AnyCanvas.hpp"
 #include "Screen/Layout.hpp"
 #include "Look/DialogLook.hpp"
 
-#include <winuser.h>
-
-WndFrame::WndFrame(const DialogLook &_look)
+WndFrame::WndFrame(const DialogLook &_look) noexcept
   :look(_look),
-   caption_color(look.text_color)
+   text_color(look.text_color)
 {
 }
 
 WndFrame::WndFrame(ContainerWindow &parent, const DialogLook &_look,
                    PixelRect rc,
-                   const WindowStyle style)
+                   const WindowStyle style) noexcept
   :look(_look),
-   caption_color(look.text_color)
+   text_color(look.text_color)
 {
   Create(parent, rc, style);
 }
 
 void
-WndFrame::SetAlignCenter()
+WndFrame::SetAlignCenter() noexcept
 {
   text_renderer.SetCenter();
   Invalidate();
 }
 
 void
-WndFrame::SetVAlignCenter()
+WndFrame::SetVAlignCenter() noexcept
 {
   text_renderer.SetVCenter();
   Invalidate();
 }
 
 void
-WndFrame::SetText(const TCHAR *_text)
+WndFrame::SetText(const TCHAR *_text) noexcept
 {
   text = _text;
+  text_renderer.InvalidateLayout();
   Invalidate();
 }
 
 unsigned
-WndFrame::GetTextHeight() const
+WndFrame::GetTextHeight() const noexcept
 {
   PixelRect rc = GetClientRect();
   const int padding = Layout::GetTextPadding();
@@ -83,7 +82,7 @@ WndFrame::OnPaint(Canvas &canvas)
   if (HaveClipping())
     canvas.Clear(look.background_brush);
 
-  canvas.SetTextColor(caption_color);
+  canvas.SetTextColor(text_color);
   canvas.SetBackgroundTransparent();
 
   canvas.Select(look.text_font);
