@@ -2,7 +2,7 @@
   Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -24,9 +24,9 @@
 #include "BigTrafficWidget.hpp"
 #include "Dialogs/Traffic/TrafficDialogs.hpp"
 #include "Math/Screen.hpp"
-#include "Screen/Canvas.hpp"
+#include "ui/canvas/Canvas.hpp"
 #include "Screen/Layout.hpp"
-#include "Screen/Key.h"
+#include "ui/event/KeyCode.hpp"
 #include "Form/Button.hpp"
 #include "Renderer/SymbolButtonRenderer.hpp"
 #include "UIState.hpp"
@@ -34,7 +34,7 @@
 #include "PageActions.hpp"
 #include "Look/Look.hpp"
 #include "Profile/Profile.hpp"
-#include "Compiler.h"
+#include "util/Compiler.h"
 #include "FLARM/Friends.hpp"
 #include "Look/FlarmTrafficLook.hpp"
 #include "Gauge/FlarmTrafficWindow.hpp"
@@ -90,7 +90,7 @@ public:
 
   void SetZoom(unsigned _zoom) {
     zoom = _zoom;
-    SetDistance(fixed(GetZoomDistance(_zoom)));
+    SetDistance(GetZoomDistance(_zoom));
   }
 
   void SetAutoZoom(bool enabled);
@@ -115,10 +115,10 @@ public:
 
 protected:
   void PaintTrafficInfo(Canvas &canvas) const;
-  void PaintClimbRate(Canvas &canvas, PixelRect rc, fixed climb_rate) const;
-  void PaintDistance(Canvas &canvas, PixelRect rc, fixed distance) const;
+  void PaintClimbRate(Canvas &canvas, PixelRect rc, double climb_rate) const;
+  void PaintDistance(Canvas &canvas, PixelRect rc, double distance) const;
   void PaintRelativeAltitude(Canvas &canvas, PixelRect rc,
-                             fixed relative_altitude) const;
+                             double relative_altitude) const;
   void PaintID(Canvas &canvas, PixelRect rc, const FlarmTraffic &traffic) const;
   void PaintTaskDirection(Canvas &canvas) const;
 
@@ -135,10 +135,10 @@ protected:
 
   /* virtual methods from class Window */
   virtual void OnCreate() override;
-  virtual bool OnMouseMove(PixelScalar x, PixelScalar y, unsigned keys) override;
-  virtual bool OnMouseDown(PixelScalar x, PixelScalar y) override;
-  virtual bool OnMouseUp(PixelScalar x, PixelScalar y) override;
-  virtual bool OnMouseDouble(PixelScalar x, PixelScalar y) override;
+  bool OnMouseMove(PixelPoint p, unsigned keys) override;
+  bool OnMouseDown(PixelPoint p) override;
+  bool OnMouseUp(PixelPoint p) override;
+  bool OnMouseDouble(PixelPoint p) override;
   virtual bool OnKeyDown(unsigned key_code) override;
   virtual void OnCancelMode() override;
 
@@ -198,7 +198,7 @@ void
 FlarmTrafficControl::CalcAutoZoom()
 {
   bool warning_mode = WarningMode();
-  RoughDistance zoom_dist = fixed(0);
+  RoughDistance zoom_dist = 0;
 
   for (auto it = data.list.begin(), end = data.list.end();
       it != end; ++it) {
@@ -208,9 +208,9 @@ FlarmTrafficControl::CalcAutoZoom()
     zoom_dist = std::max(it->distance, zoom_dist);
   }
 
-  fixed zoom_dist2 = zoom_dist;
+  double zoom_dist2 = zoom_dist;
   for (unsigned i = 0; i <= 4; i++) {
-    if (i == 4 || fixed(GetZoomDistance(i)) >= zoom_dist2) {
+    if (i == 4 || GetZoomDistance(i) >= zoom_dist2) {
       SetZoom(i);
       break;
     }
@@ -273,38 +273,36 @@ FlarmTrafficControl::ZoomIn()
 void
 FlarmTrafficControl::PaintTaskDirection(Canvas &canvas) const
 {
-  if (negative(task_direction.Degrees()))
+  if (task_direction.IsNegative())
     return;
 
   canvas.Select(look.radar_pen);
   canvas.SelectHollowBrush();
 
-  RasterPoint triangle[4];
+  BulkPixelPoint triangle[3];
   triangle[0].x = 0;
   triangle[0].y = -radius / Layout::FastScale(1) + 15;
   triangle[1].x = 7;
   triangle[1].y = triangle[0].y + 30;
   triangle[2].x = -triangle[1].x;
   triangle[2].y = triangle[1].y;
-  triangle[3].x = triangle[0].x;
-  triangle[3].y = triangle[0].y;
 
-  PolygonRotateShift(triangle, 4, radar_mid,
+  PolygonRotateShift(triangle, 3, radar_mid,
                      task_direction - (enable_north_up ?
                                        Angle::Zero() : heading));
 
   // Draw the arrow
-  canvas.DrawPolygon(triangle, 4);
+  canvas.DrawPolygon(triangle, 3);
 }
 
 void
 FlarmTrafficControl::PaintClimbRate(Canvas &canvas, PixelRect rc,
-                                    fixed climb_rate) const
+                                    double climb_rate) const
 {
   // Paint label
   canvas.Select(look.info_labels_font);
-  const unsigned label_width = canvas.CalcTextSize(_("Vario")).cx;
-  canvas.DrawText(rc.right - label_width, rc.top, _("Vario"));
+  const unsigned label_width = canvas.CalcTextSize(_("Vario")).width;
+  canvas.DrawText(rc.GetTopRight().At(-(int)label_width, 0), _("Vario"));
 
   // Format climb rate
   TCHAR buffer[20];
@@ -313,44 +311,47 @@ FlarmTrafficControl::PaintClimbRate(Canvas &canvas, PixelRect rc,
 
   // Calculate unit size
   canvas.Select(look.info_units_font);
-  const unsigned unit_width = UnitSymbolRenderer::GetSize(canvas, unit).cx;
+  const unsigned unit_width = UnitSymbolRenderer::GetSize(canvas, unit).width;
   const unsigned unit_height =
       UnitSymbolRenderer::GetAscentHeight(look.info_units_font, unit);
 
-  UPixelScalar space_width = unit_width / 3;
+  unsigned space_width = unit_width / 3;
 
   // Calculate value size
   canvas.Select(look.info_values_font);
   const unsigned value_height = look.info_values_font.GetAscentHeight();
-  const unsigned value_width = canvas.CalcTextSize(buffer).cx;
+  const unsigned value_width = canvas.CalcTextSize(buffer).width;
 
   // Calculate positions
   const int max_height = std::max(unit_height, value_height);
   const int y = rc.top + look.info_units_font.GetHeight() + max_height;
 
+  const int unit_x = rc.right - unit_width;
+  const int unit_y = y - unit_height;
+
+  const int value_x = unit_x - space_width - value_width;
+  const int value_y = y - value_height;
+
   // Paint value
-  canvas.DrawText(rc.right - unit_width - space_width - value_width,
-                  y - value_height,
-                  buffer);
+  canvas.DrawText({value_x, value_y}, buffer);
 
   // Paint unit
   canvas.Select(look.info_units_font);
-  UnitSymbolRenderer::Draw(canvas,
-                           RasterPoint(rc.right - unit_width, y - unit_height),
+  UnitSymbolRenderer::Draw(canvas, {unit_x, unit_y},
                            unit, look.unit_fraction_pen);
 }
 
 void
 FlarmTrafficControl::PaintDistance(Canvas &canvas, PixelRect rc,
-                                   fixed distance) const
+                                   double distance) const
 {
   // Format distance
   TCHAR buffer[20];
-  Unit unit = FormatUserDistanceSmart(distance, buffer, false, fixed(1000));
+  Unit unit = FormatUserDistanceSmart(distance, buffer, false, 1000);
 
   // Calculate unit size
   canvas.Select(look.info_units_font);
-  const unsigned unit_width = UnitSymbolRenderer::GetSize(canvas, unit).cx;
+  const unsigned unit_width = UnitSymbolRenderer::GetSize(canvas, unit).width;
   const unsigned unit_height =
       UnitSymbolRenderer::GetAscentHeight(look.info_units_font, unit);
 
@@ -359,32 +360,33 @@ FlarmTrafficControl::PaintDistance(Canvas &canvas, PixelRect rc,
   // Calculate value size
   canvas.Select(look.info_values_font);
   const unsigned value_height = look.info_values_font.GetAscentHeight();
-  const unsigned value_width = canvas.CalcTextSize(buffer).cx;
+  const unsigned value_width = canvas.CalcTextSize(buffer).width;
 
   // Calculate positions
   const unsigned max_height = std::max(unit_height, value_height);
 
+  const auto p0 = rc.GetBottomLeft();
+
   // Paint value
-  canvas.DrawText(rc.left, rc.bottom - value_height, buffer);
+  canvas.DrawText(p0.At(0, -(int)value_height), buffer);
 
   // Paint unit
   canvas.Select(look.info_units_font);
   UnitSymbolRenderer::Draw(canvas,
-                           RasterPoint(rc.left + value_width + space_width,
-                                       rc.bottom - unit_height),
+                           p0.At(value_width + space_width,
+                                 -(int)unit_height),
                            unit, look.unit_fraction_pen);
 
 
   // Paint label
   canvas.Select(look.info_labels_font);
-  canvas.DrawText(rc.left,
-                  rc.bottom - max_height - look.info_labels_font.GetHeight(),
+  canvas.DrawText(p0.At(0, -int(max_height + look.info_labels_font.GetHeight())),
                   _("Distance"));
 }
 
 void
 FlarmTrafficControl::PaintRelativeAltitude(Canvas &canvas, PixelRect rc,
-                                           fixed relative_altitude) const
+                                           double relative_altitude) const
 {
   // Format relative altitude
   TCHAR buffer[20];
@@ -393,7 +395,7 @@ FlarmTrafficControl::PaintRelativeAltitude(Canvas &canvas, PixelRect rc,
 
   // Calculate unit size
   canvas.Select(look.info_units_font);
-  const unsigned unit_width = UnitSymbolRenderer::GetSize(canvas, unit).cx;
+  const unsigned unit_width = UnitSymbolRenderer::GetSize(canvas, unit).width;
   const unsigned unit_height =
       UnitSymbolRenderer::GetAscentHeight(look.info_units_font, unit);
 
@@ -402,29 +404,29 @@ FlarmTrafficControl::PaintRelativeAltitude(Canvas &canvas, PixelRect rc,
   // Calculate value size
   canvas.Select(look.info_values_font);
   const unsigned value_height = look.info_values_font.GetAscentHeight();
-  const unsigned value_width = canvas.CalcTextSize(buffer).cx;
+  const unsigned value_width = canvas.CalcTextSize(buffer).width;
 
   // Calculate positions
   const unsigned max_height = std::max(unit_height, value_height);
 
+  const auto p0 = rc.GetBottomRight();
+
   // Paint value
-  canvas.DrawText(rc.right - unit_width - space_width - value_width,
-                  rc.bottom - value_height,
+  canvas.DrawText(p0.At(-int(unit_width + space_width + value_width),
+                        -(int)value_height),
                   buffer);
 
   // Paint unit
   canvas.Select(look.info_units_font);
   UnitSymbolRenderer::Draw(canvas,
-                           RasterPoint(rc.right - unit_width,
-                                       rc.bottom - unit_height),
+                           p0.At(-(int)unit_width, -(int)unit_height),
                            unit, look.unit_fraction_pen);
 
 
   // Paint label
   canvas.Select(look.info_labels_font);
-  const unsigned label_width = canvas.CalcTextSize(_("Rel. Alt.")).cx;
-  canvas.DrawText(rc.right - label_width,
-                  rc.bottom - max_height - look.info_labels_font.GetHeight(),
+  const unsigned label_width = canvas.CalcTextSize(_("Rel. Alt.")).width;
+  canvas.DrawText(p0.At(-(int)label_width,  -int(max_height + look.info_labels_font.GetHeight())),
                   _("Rel. Alt."));
 }
 
@@ -471,14 +473,14 @@ FlarmTrafficControl::PaintID(Canvas &canvas, PixelRect rc,
       }
 
       canvas.SelectNullPen();
-      canvas.DrawCircle(rc.left + Layout::FastScale(7), rc.top + (font_size / 2),
-                    Layout::FastScale(7));
+      canvas.DrawCircle(rc.GetTopLeft().At(Layout::FastScale(7u), (font_size / 2)),
+                        Layout::FastScale(7u));
 
       rc.left += Layout::FastScale(16);
     }
   }
 
-  canvas.DrawText(rc.left, rc.top, buffer);
+  canvas.DrawText(rc.GetTopLeft(), buffer);
 }
 
 /**
@@ -563,36 +565,138 @@ FlarmTrafficControl::OpenDetails()
   dlgFlarmTrafficDetailsShowModal(traffic->id);
 }
 
-void
-TrafficWidget::OpenDetails()
+static Button
+MakeSymbolButton(ContainerWindow &parent, const ButtonLook &look,
+                const TCHAR *caption,
+                const PixelRect &rc,
+                Button::Callback callback) noexcept
 {
-  view->OpenDetails();
+  return Button(parent, rc, WindowStyle(),
+                std::make_unique<SymbolButtonRenderer>(look, caption),
+                std::move(callback));
+}
+
+struct TrafficWidget::Windows {
+  Button zoom_in_button, zoom_out_button;
+  Button previous_item_button, next_item_button;
+  Button details_button;
+  Button close_button;
+
+  FlarmTrafficControl view;
+
+  Windows(TrafficWidget &widget, ContainerWindow &parent, const PixelRect &r,
+          const ButtonLook &button_look, const FlarmTrafficLook &flarm_look)
+    :zoom_in_button(MakeSymbolButton(parent, button_look, _T("+"), r,
+                                     [&widget](){ widget.ZoomIn(); })),
+     zoom_out_button(MakeSymbolButton(parent, button_look,
+                                    _T("-"), r,
+                                      [&widget](){ widget.ZoomOut(); })),
+     previous_item_button(MakeSymbolButton(parent, button_look,
+                                           _T("<"), r,
+                                           [&widget](){ widget.PreviousTarget(); })),
+     next_item_button(MakeSymbolButton(parent, button_look,
+                                       _T(">"), r,
+                                       [&widget](){ widget.NextTarget(); })),
+     details_button(parent, button_look,
+                    _("Details"), r, WindowStyle(),
+                    [&widget](){ widget.OpenDetails(); }),
+     close_button(parent, button_look,
+                  _("Close"), r, WindowStyle(),
+                  [](){ PageActions::Restore(); }),
+     view(flarm_look)
+  {
+    view.Create(parent, r);
+    UpdateLayout(r);
+  }
+
+  void UpdateLayout(const PixelRect &rc) noexcept;
+};
+
+void
+TrafficWidget::Windows::UpdateLayout(const PixelRect &rc) noexcept
+{
+  view.Move(rc);
+
+  const unsigned margin = Layout::Scale(1);
+  const unsigned button_height = Layout::GetMinimumControlHeight();
+  const unsigned button_width = std::max(unsigned(rc.right / 6),
+                                         button_height);
+
+  const int x1 = rc.right / 2;
+  const int x0 = x1 - button_width;
+  const int x2 = x1 + button_width;
+
+  const int y0 = margin;
+  const int y1 = y0 + button_height;
+  const int y3 = rc.bottom - margin;
+  const int y2 = y3 - button_height;
+
+  PixelRect button_rc;
+
+  button_rc.left = x0;
+  button_rc.top = y0;
+  button_rc.right = x1 - margin;
+  button_rc.bottom = y1;
+  zoom_in_button.Move(button_rc);
+
+  button_rc.left = x1;
+  button_rc.right = x2 - margin;
+  zoom_out_button.Move(button_rc);
+
+  button_rc.left = x0;
+  button_rc.top = y2;
+  button_rc.right = x1 - margin;
+  button_rc.bottom = y3;
+  previous_item_button.Move(button_rc);
+
+  button_rc.left = x1;
+  button_rc.right = x2 - margin;
+  next_item_button.Move(button_rc);
+
+  button_rc.left = margin;
+  button_rc.top = button_height * 3 / 2;
+  button_rc.right = button_rc.left + Layout::Scale(50);
+  button_rc.bottom = button_rc.top + button_height;
+  details_button.Move(button_rc);
+
+  button_rc.right = rc.right - margin;
+  button_rc.left = button_rc.right - Layout::Scale(50);
+  close_button.Move(button_rc);
+}
+
+TrafficWidget::TrafficWidget() noexcept = default;
+TrafficWidget::~TrafficWidget() noexcept = default;
+
+void
+TrafficWidget::OpenDetails() noexcept
+{
+  windows->view.OpenDetails();
 }
 
 void
-TrafficWidget::ZoomIn()
+TrafficWidget::ZoomIn() noexcept
 {
-  view->ZoomIn();
+  windows->view.ZoomIn();
   UpdateButtons();
 }
 
 void
-TrafficWidget::ZoomOut()
+TrafficWidget::ZoomOut() noexcept
 {
-  view->ZoomOut();
+  windows->view.ZoomOut();
   UpdateButtons();
 }
 
 void
-TrafficWidget::PreviousTarget()
+TrafficWidget::PreviousTarget() noexcept
 {
-  view->PrevTarget();
+  windows->view.PrevTarget();
 }
 
 void
-TrafficWidget::NextTarget()
+TrafficWidget::NextTarget() noexcept
 {
-  view->NextTarget();
+  windows->view.NextTarget();
 }
 
 void
@@ -607,49 +711,49 @@ FlarmTrafficControl::SwitchData()
 }
 
 void
-TrafficWidget::SwitchData()
+TrafficWidget::SwitchData() noexcept
 {
-  view->SwitchData();
+  windows->view.SwitchData();
 }
 
 bool
-TrafficWidget::GetAutoZoom() const
+TrafficWidget::GetAutoZoom() const noexcept
 {
-  return view->GetAutoZoom();
+  return windows->view.GetAutoZoom();
 }
 
 void
-TrafficWidget::SetAutoZoom(bool value)
+TrafficWidget::SetAutoZoom(bool value) noexcept
 {
-  view->SetAutoZoom(value);
+  windows->view.SetAutoZoom(value);
 }
 
 void
-TrafficWidget::ToggleAutoZoom()
+TrafficWidget::ToggleAutoZoom() noexcept
 {
-  view->ToggleAutoZoom();
+  windows->view.ToggleAutoZoom();
 }
 
 bool
-TrafficWidget::GetNorthUp() const
+TrafficWidget::GetNorthUp() const noexcept
 {
-  return view->GetNorthUp();
+  return windows->view.GetNorthUp();
 }
 
 void
-TrafficWidget::SetNorthUp(bool value)
+TrafficWidget::SetNorthUp(bool value) noexcept
 {
-  view->SetAutoZoom(value);
+  windows->view.SetAutoZoom(value);
 }
 
 void
-TrafficWidget::ToggleNorthUp()
+TrafficWidget::ToggleNorthUp() noexcept
 {
-  view->ToggleNorthUp();
+  windows->view.ToggleNorthUp();
 }
 
 void
-TrafficWidget::Update()
+TrafficWidget::Update() noexcept
 {
   const NMEAInfo &basic = CommonInterface::Basic();
   const DerivedInfo &calculated = CommonInterface::Calculated();
@@ -666,11 +770,11 @@ TrafficWidget::Update()
     return;
   }
 
-  view->Update(basic.track,
+  windows->view.Update(basic.track,
                basic.flarm.traffic,
                CommonInterface::GetComputerSettings().team_code);
 
-  view->UpdateTaskDirection(calculated.task_stats.task_valid &&
+  windows->view.UpdateTaskDirection(calculated.task_stats.task_valid &&
                             calculated.task_stats.current_leg.solution_remaining.IsOk(),
                             calculated.task_stats.
                             current_leg.solution_remaining.cruise_track_bearing);
@@ -679,29 +783,28 @@ TrafficWidget::Update()
 }
 
 bool
-FlarmTrafficControl::OnMouseMove(PixelScalar x, PixelScalar y,
-                                 gcc_unused unsigned keys)
+FlarmTrafficControl::OnMouseMove(PixelPoint p, gcc_unused unsigned keys)
 {
   if (dragging)
-    gestures.Update(x, y);
+    gestures.Update(p);
 
   return true;
 }
 
 bool
-FlarmTrafficControl::OnMouseDown(PixelScalar x, PixelScalar y)
+FlarmTrafficControl::OnMouseDown(PixelPoint p)
 {
   if (!dragging) {
     dragging = true;
     SetCapture();
-    gestures.Start(x, y, Layout::Scale(20));
+    gestures.Start(p, Layout::Scale(20));
   }
 
   return true;
 }
 
 bool
-FlarmTrafficControl::OnMouseUp(PixelScalar x, PixelScalar y)
+FlarmTrafficControl::OnMouseUp(PixelPoint p)
 {
   if (dragging) {
     StopDragging();
@@ -712,13 +815,13 @@ FlarmTrafficControl::OnMouseUp(PixelScalar x, PixelScalar y)
   }
 
   if (!WarningMode())
-    SelectNearTarget(x, y, Layout::Scale(15));
+    SelectNearTarget(p, Layout::Scale(15));
 
   return true;
 }
 
 bool
-FlarmTrafficControl::OnMouseDouble(PixelScalar x, PixelScalar y)
+FlarmTrafficControl::OnMouseDouble(PixelPoint p)
 {
   StopDragging();
   InputEvents::ShowMenu();
@@ -776,16 +879,6 @@ FlarmTrafficControl::OnKeyDown(unsigned key_code)
 
     ZoomOut();
     return true;
-
-#ifdef GNAV
-  case '6':
-    PrevTarget();
-    return true;
-
-  case '7':
-    NextTarget();
-    return true;
-#endif
   }
 
   return FlarmTrafficWindow::OnKeyDown(key_code) ||
@@ -793,146 +886,41 @@ FlarmTrafficControl::OnKeyDown(unsigned key_code)
 }
 
 void
-TrafficWidget::UpdateLayout()
+TrafficWidget::UpdateLayout() noexcept
 {
-  const PixelRect rc = GetContainer().GetClientRect();
-  view->Move(rc);
-
-#ifndef GNAV
-  const unsigned margin = Layout::Scale(1);
-  const unsigned button_height = Layout::GetMinimumControlHeight();
-  const unsigned button_width = std::max(unsigned(rc.right / 6),
-                                         button_height);
-
-  const PixelScalar x1 = rc.right / 2;
-  const PixelScalar x0 = x1 - button_width;
-  const PixelScalar x2 = x1 + button_width;
-
-  const int y0 = margin;
-  const int y1 = y0 + button_height;
-  const int y3 = rc.bottom - margin;
-  const int y2 = y3 - button_height;
-
-  PixelRect button_rc;
-
-  button_rc.left = x0;
-  button_rc.top = y0;
-  button_rc.right = x1 - margin;
-  button_rc.bottom = y1;
-  zoom_in_button->Move(button_rc);
-
-  button_rc.left = x1;
-  button_rc.right = x2 - margin;
-  zoom_out_button->Move(button_rc);
-
-  button_rc.left = x0;
-  button_rc.top = y2;
-  button_rc.right = x1 - margin;
-  button_rc.bottom = y3;
-  previous_item_button->Move(button_rc);
-
-  button_rc.left = x1;
-  button_rc.right = x2 - margin;
-  next_item_button->Move(button_rc);
-
-  button_rc.left = margin;
-  button_rc.top = button_height * 3 / 2;
-  button_rc.right = button_rc.left + Layout::Scale(50);
-  button_rc.bottom = button_rc.top + button_height;
-  details_button->Move(button_rc);
-
-  button_rc.right = rc.right - margin;
-  button_rc.left = button_rc.right - Layout::Scale(50);
-  close_button->Move(button_rc);
-#endif
+  windows->UpdateLayout(GetContainer().GetClientRect());
 }
 
 void
-TrafficWidget::UpdateButtons()
+TrafficWidget::UpdateButtons() noexcept
 {
-#ifndef GNAV
-  const bool unlocked = !view->WarningMode();
+  const bool unlocked = !windows->view.WarningMode();
   const TrafficList &traffic = CommonInterface::Basic().flarm.traffic;
   const bool not_empty = !traffic.IsEmpty();
   const bool two_or_more = traffic.GetActiveTrafficCount() >= 2;
 
-  zoom_in_button->SetEnabled(unlocked && view->CanZoomIn());
-  zoom_out_button->SetEnabled(unlocked && view->CanZoomOut());
-  previous_item_button->SetEnabled(unlocked && two_or_more);
-  next_item_button->SetEnabled(unlocked && two_or_more);
-  details_button->SetEnabled(unlocked && not_empty);
-#endif
+  windows->zoom_in_button.SetEnabled(unlocked && windows->view.CanZoomIn());
+  windows->zoom_out_button.SetEnabled(unlocked && windows->view.CanZoomOut());
+  windows->previous_item_button.SetEnabled(unlocked && two_or_more);
+  windows->next_item_button.SetEnabled(unlocked && two_or_more);
+  windows->details_button.SetEnabled(unlocked && not_empty);
 }
 
-#ifndef GNAV
-
-static Button *
-NewSymbolButton(ContainerWindow &parent, const ButtonLook &look,
-                const TCHAR *caption,
-                const PixelRect &rc,
-                ActionListener &listener, int id)
-{
-  return new Button(parent, rc, WindowStyle(),
-                    new SymbolButtonRenderer(look, caption),
-                    listener, id);
-}
-
-#endif
-
 void
-TrafficWidget::Prepare(ContainerWindow &parent, const PixelRect &_rc)
+TrafficWidget::Prepare(ContainerWindow &parent, const PixelRect &_rc) noexcept
 {
   ContainerWidget::Prepare(parent, _rc);
 
   const Look &look = UIGlobals::GetLook();
 
-  const PixelRect rc = GetContainer().GetClientRect();
-
-#ifndef GNAV
-  zoom_in_button = NewSymbolButton(GetContainer(), look.dialog.button,
-                                   _T("+"), rc, *this, ZOOM_IN);
-  zoom_out_button = NewSymbolButton(GetContainer(), look.dialog.button,
-                                    _T("-"), rc, *this, ZOOM_OUT);
-  previous_item_button = NewSymbolButton(GetContainer(), look.dialog.button,
-                                         _T("<"), rc, *this, PREVIOUS_ITEM);
-  next_item_button = NewSymbolButton(GetContainer(), look.dialog.button,
-                                     _T(">"), rc, *this, NEXT_ITEM);
-  details_button = new Button(GetContainer(), look.dialog.button,
-                              _("Details"), rc, WindowStyle(),
-                              *this, DETAILS);
-  close_button = new Button(GetContainer(), look.dialog.button,
-                            _("Close"), rc, WindowStyle(),
-                            *this, CLOSE);
-#endif
-
-  WindowStyle style;
-  style.EnableDoubleClicks();
-
-  view = new FlarmTrafficControl(look.flarm_dialog);
-  view->Create(GetContainer(), rc, style);
-
+  windows = std::make_unique<Windows>(*this, GetContainer(),
+                                      GetContainer().GetClientRect(),
+                                      look.dialog.button, look.flarm_dialog);
   UpdateLayout();
 }
 
 void
-TrafficWidget::Unprepare()
-{
-#ifndef GNAV
-  delete zoom_in_button;
-  delete zoom_out_button;
-  delete previous_item_button;
-  delete next_item_button;
-  delete details_button;
-  delete close_button;
-#endif
-
-  delete view;
-
-  ContainerWidget::Unprepare();
-}
-
-void
-TrafficWidget::Show(const PixelRect &rc)
+TrafficWidget::Show(const PixelRect &rc) noexcept
 {
   // Update Radar and Selection for the first time
   Update();
@@ -940,23 +928,21 @@ TrafficWidget::Show(const PixelRect &rc)
   ContainerWidget::Show(rc);
   UpdateLayout();
 
-#ifndef GNAV
   /* show the "Close" button only if this is a "special" page */
-  close_button->SetVisible(CommonInterface::GetUIState().pages.special_page.IsDefined());
-#endif
+  windows->close_button.SetVisible(CommonInterface::GetUIState().pages.special_page.IsDefined());
 
   CommonInterface::GetLiveBlackboard().AddListener(*this);
 }
 
 void
-TrafficWidget::Hide()
+TrafficWidget::Hide() noexcept
 {
   CommonInterface::GetLiveBlackboard().RemoveListener(*this);
   ContainerWidget::Hide();
 }
 
 void
-TrafficWidget::Move(const PixelRect &rc)
+TrafficWidget::Move(const PixelRect &rc) noexcept
 {
   ContainerWidget::Move(rc);
 
@@ -965,46 +951,12 @@ TrafficWidget::Move(const PixelRect &rc)
 
 
 bool
-TrafficWidget::SetFocus()
+TrafficWidget::SetFocus() noexcept
 {
-  view->SetFocus();
+  windows->view.SetFocus();
   return true;
 }
 
-#ifndef GNAV
-
-void
-TrafficWidget::OnAction(int id)
-{
-  switch ((Action)id) {
-  case CLOSE:
-    PageActions::Restore();
-    break;
-
-  case DETAILS:
-    OpenDetails();
-    break;
-
-  case PREVIOUS_ITEM:
-    PreviousTarget();
-    break;
-
-  case NEXT_ITEM:
-    NextTarget();
-    break;
-
-  case ZOOM_IN:
-    ZoomIn();
-    break;
-
-  case ZOOM_OUT:
-    ZoomOut();
-    break;
-  }
-}
-
-#endif
-
 void
 TrafficWidget::OnGPSUpdate(const MoreData &basic)
 {
