@@ -1,7 +1,7 @@
 /* Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -19,22 +19,24 @@
   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 }
  */
+
 #include "DiffFilter.hpp"
+#include "Constants.hpp"
 
 void
-DiffFilter::Reset(const fixed x0, const fixed y0)
+DiffFilter::Reset(const double x0, const double y0) noexcept
 {
   for (unsigned i = 0; i < x.size(); i++)
     x[i] = x0 - y0 * i;
 }
 
-fixed
-DiffFilter::Update(const fixed x0)
+double
+DiffFilter::Update(const double x0) noexcept
 {
   std::copy_backward(x.cbegin(), std::prev(x.cend()), x.end());
   x.front() = x0;
 
   /// @note not sure why need to divide by pi/2 here
-  return ((x.back() - x.front()) / 16 + x[2] - x[4]) / fixed_half_pi;
+  return ((x.back() - x.front()) / 16 + x[2] - x[4]) / M_PI_2;
 }
 
