@@ -25,6 +25,12 @@ Copyright_License {
 
 #include <stdio.h>
 
+void
+ConsoleOperationEnvironment::SetErrorMessage(const TCHAR *text) noexcept
+{
+  _ftprintf(stderr, _T("ERROR: %s\n"), text);
+}
+
 void
 ConsoleOperationEnvironment::SetText(const TCHAR *text) noexcept
 {
