@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -25,11 +25,10 @@ Copyright_License {
 #define XCSOAR_TASK_VALIDATION_ERROR_STRINGS_HPP
 
 #include "Engine/Task/Factory/ValidationError.hpp"
-#include "Compiler.h"
 
 #include <tchar.h>
 
-gcc_pure
+[[gnu::const]]
 const TCHAR *
 getTaskValidationErrors(const TaskValidationErrorSet v);
 
