@@ -3,7 +3,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -29,9 +29,7 @@ Copyright_License {
 
 struct ShapePoint : FloatPoint2D {
   ShapePoint() = default;
-
-  template<typename... Args>
-  constexpr ShapePoint(Args&&... args):FloatPoint2D(args...) {}
+  using FloatPoint2D::FloatPoint2D;
 };
 
 typedef ShapePoint::scalar_type ShapeScalar;
