@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -24,19 +24,17 @@ Copyright_License {
 #ifndef WAYPOINT_WRITER_HPP
 #define WAYPOINT_WRITER_HPP
 
-#include "Math/fixed.hpp"
 #include "Engine/Waypoint/Origin.hpp"
 
 struct Waypoint;
 class Waypoints;
-class TextWriter;
-class Angle;
+class BufferedOutputStream;
 
 void
-WriteCup(TextWriter &writer, const Waypoint &wp);
+WriteCup(BufferedOutputStream &writer, const Waypoint &wp);
 
 void
-WriteCup(TextWriter &writer, const Waypoints &waypoints,
+WriteCup(BufferedOutputStream &writer, const Waypoints &waypoints,
          WaypointOrigin origin);
 
 #endif
