@@ -33,7 +33,9 @@ Copyright_License {
 #include <tchar.h>
 
 struct PCMetSettings;
-class JobRunner;
+class CurlGlobal;
+class ProgressListener;
+namespace Co { template<typename T> class Task; }
 
 namespace PCMet {
 
@@ -73,15 +75,15 @@ struct Overlay {
     :run_time(_run_time), valid_time(_valid_time), path(std::move(_path)) {}
 
   bool IsDefined() const {
-    return !path.IsNull();
+    return path != nullptr;
   }
 };
 
-Overlay
+Co::Task<Overlay>
 DownloadOverlay(const OverlayInfo &info, BrokenDateTime now_utc,
                 const PCMetSettings &settings,
-                JobRunner &runner);
+                CurlGlobal &curl, ProgressListener &progress);
 
-};
+} // namespace PCMet
 
 #endif
