@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -24,17 +24,17 @@ Copyright_License {
 #ifndef XCSOAR_WEATHER_UI_STATE_HPP
 #define XCSOAR_WEATHER_UI_STATE_HPP
 
-#include "Time/BrokenTime.hpp"
+#include "time/BrokenTime.hpp"
 
 /**
  * The state of weather display on the user interface.
  */
 struct WeatherUIState {
   /**
-   * The map index being displayed.  0 means no weather map (normal
+   * The map index being displayed.  -1 means no weather map (normal
    * terrain display).
    */
-  unsigned map;
+  int map;
 
   /**
    * The weather forecast time that shall be displayed.
@@ -42,7 +42,7 @@ struct WeatherUIState {
   BrokenTime time;
 
   void Clear() {
-    map = 0;
+    map = -1;
     time = BrokenTime::Invalid();
   }
 };
