@@ -353,9 +353,7 @@ XML::GetNextToken(Parser *pXML)
     // If we haven't found a short hand closing tag then drop into the
     // text process
 
-#if GCC_CHECK_VERSION(7,0)
     [[fallthrough]];
-#endif
 
     // Other characters
   default:
