@@ -33,9 +33,15 @@ Copyright_License {
 #include <winuser.h>
 
 Bitmap::Bitmap(Bitmap &&src) noexcept
-  :bitmap(src.bitmap)
+  :bitmap(std::exchange(src.bitmap, nullptr))
 {
-  src.bitmap = nullptr;
+}
+
+Bitmap &Bitmap::operator=(Bitmap &&src) noexcept
+{
+  using std::swap;
+  swap(bitmap, src.bitmap);
+  return *this;
 }
 
 bool
